# PyDont
```python
from pydont import dont

ask = input("Do you think that this is funny? (yes/no) : ")

if ask != "yes":
    dont()
else:
    print("Thank you!")
```

## Syntax:
`dont()` -- equivalent to using `pass`. for the memes.